public class Auto
{
     int ppm=100;
     double x=0.0,y=0.0,w=0.4,h=0.2,phi=0.0;
     int R=0,G=0,B=255;
     
     /**Eckpunkte /Cornerpoints:
                vL
        p5      p4      p3            
        |-------|-------|             ^
        |       *[x,y]  |    ^        | h
        |_______|_______|    | PHI    v
        p0      p1      p2
                vR
                
        <------ w ------>        
     */
     double[][] p = new double[6][2];
     
     public void setPixelPerMeter(int ppm)
     {
         this.ppm=ppm;
     }
     
     public Auto()
     {
          updateCornerpoints();
     }
     public Auto(double x,double y,double w,double h, double phi, int R, int G, int B)
     {
          init(x,y,w,h,phi,R,G,B);
          updateCornerpoints();
     }
     
     public void init(double x,double y,double w,double h, double phi, int R, int G, int B)
     {
         this.x=x;
         this.y=y;
         this.w=w;
         this.h=h;
         this.phi=phi;
         this.R=R;
         this.G=G;
         this.B=B;
     }
 
     /**
     
          | cos  -sin |   
      T = |           |
          | sin   cos |
     
     */
     public void updateCornerpoints()
     {
          p[0][0] = (-w/2.0)*Math.cos(phi) - (-h/2.0)*Math.sin(phi);           
          p[0][1] = (-w/2.0)*Math.sin(phi) + (-h/2.0)*Math.cos(phi);           
          p[1][0] = 0.0                    - (-h/2.0)*Math.sin(phi);           
          p[1][1] = 0.0                    + (-h/2.0)*Math.cos(phi);           
          p[2][0] = (w/2.0)*Math.cos(phi)  - (-h/2.0)*Math.sin(phi);           
          p[2][1] = (w/2.0)*Math.sin(phi)  + (-h/2.0)*Math.cos(phi);           
          p[3][0] = (w/2.0)*Math.cos(phi)  - (h/2.0)*Math.sin(phi);           
          p[3][1] = (w/2.0)*Math.sin(phi)  + (h/2.0)*Math.cos(phi);           
          p[4][0] = 0.0                    - (h/2.0)*Math.sin(phi);           
          p[4][1] = 0.0                    + (h/2.0)*Math.cos(phi);           
          p[5][0] = (-w/2.0)*Math.cos(phi) - (h/2.0)*Math.sin(phi);           
          p[5][1] = (-w/2.0)*Math.sin(phi) + (h/2.0)*Math.cos(phi);           
     }
     
     float p2x(double[] p,float xoffpx, float yoffpx)
     {
         return (float)(p[0]+(double)xoffpx/(double)ppm)*(float)ppm;
     }
     float p2y(double[] p,float xoffpx, float yoffpx)
     {
         return (float)(((double)yoffpx/(double)ppm)-p[1])*(float)ppm;
     }
     
     public void show(float xoffpx, float yoffpx)
     {
          stroke(R,G,B);
          line(p2x(p[0],xoffpx,yoffpx),p2y(p[0],xoffpx,yoffpx),p2x(p[2],xoffpx,yoffpx),p2y(p[2],xoffpx,yoffpx));         
          line(p2x(p[2],xoffpx,yoffpx),p2y(p[2],xoffpx,yoffpx),p2x(p[3],xoffpx,yoffpx),p2y(p[3],xoffpx,yoffpx));         
          line(p2x(p[3],xoffpx,yoffpx),p2y(p[3],xoffpx,yoffpx),p2x(p[5],xoffpx,yoffpx),p2y(p[5],xoffpx,yoffpx));         
          line(p2x(p[5],xoffpx,yoffpx),p2y(p[5],xoffpx,yoffpx),p2x(p[0],xoffpx,yoffpx),p2y(p[0],xoffpx,yoffpx));         
          line(p2x(p[1],xoffpx,yoffpx),p2y(p[1],xoffpx,yoffpx),p2x(p[4],xoffpx,yoffpx),p2y(p[4],xoffpx,yoffpx));         
     }
}
